package org.rssloteriadelestado.android;

import java.io.StringWriter;
import java.util.ArrayList;
import java.util.List;

import org.example.proyectosojoa.R;
import org.xmlpull.v1.XmlSerializer;

import android.app.ListActivity;
import android.content.Intent;
import android.os.Bundle;
import android.os.StrictMode;
import android.util.Log;
import android.util.Xml;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.ListView;

public class MessageList extends ListActivity {
	
	private List<Message> messages;
	
    @Override
    public void onCreate(Bundle icicle) {
        super.onCreate(icicle);
        setContentView(R.layout.main);
        
    
        StrictMode.setThreadPolicy(new StrictMode.ThreadPolicy.Builder().
                permitNetwork().build());
    
        loadFeed(ParserType.LAPRIMI);
    }
    
	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		super.onCreateOptionsMenu(menu);
	
		getMenuInflater().inflate(R.menu.menu,  menu);
				
		return true;
	}

	
	@Override public boolean onOptionsItemSelected(MenuItem item) {

	       switch (item.getItemId()) {
	       case R.id.bono:
	    	   this.loadFeed(ParserType.BONOLOTO);
	             break;
	       case R.id.lote:
	    	   this.loadFeed(ParserType.LOT_NAC);
	             break;
	       case R.id.euro:
	    	   this.loadFeed(ParserType.EURO_MIL);
	             break;
	       case R.id.gord:
	    	   this.loadFeed(ParserType.ELGORDO);
	             break;
	       case R.id.primi:
	    	   this.loadFeed(ParserType.LAPRIMI);
	             break;
	       case R.id.quini:
	    	   this.loadFeed(ParserType.QUINIELA);
	             break;
	             
	       }

	       return true; /** true -> consumimos el item, no se propaga*/

	}
	
	

	@Override
	protected void onListItemClick(ListView l, View v, int position, long id) {
		super.onListItemClick(l, v, position, id);
		Intent viewMessage = new Intent(this,AcercaDe.class);
		
		Bundle bundle = new Bundle ();
		bundle.putString("NOMBRE",messages.get(position).getDescription());
		viewMessage.putExtras(bundle);		
			
			this.startActivity(viewMessage);
			}
	


		
	private void loadFeed(ParserType type){
    	try{
    		Log.i("AndroidLoteria", "ParserType="+type.name());
	    	FeedParser parser = FeedParserFactory.getParser(type);
	    	long start = System.currentTimeMillis();
	    	messages = parser.parse();
	    	long duration = System.currentTimeMillis() - start;
	    	Log.i("AndroidLoteria", "Parser duration=" + duration);
	    	String xml = writeXml();
	    	Log.i("AndroidLoteria", xml);
	    	List<String> titles = new ArrayList<String>(messages.size());
	    	for (Message msg : messages){
	    		titles.add(msg.getTitle());
	    	}
	    	ArrayAdapter<String> adapter = 
	    		new ArrayAdapter<String>(this, R.layout.row,titles);
	    	this.setListAdapter(adapter);
    	} catch (Throwable t){
    		Log.e("AndroidLoteria",t.getMessage(),t);
    	}
    }
    
	private String writeXml(){
		XmlSerializer serializer = Xml.newSerializer();
		StringWriter writer = new StringWriter();
		try {
			serializer.setOutput(writer);
			serializer.startDocument("UTF_8", true);
			serializer.startTag("", "messages");
			serializer.attribute("", "number", String.valueOf(messages.size()));
			for (Message msg: messages){
				serializer.startTag("", "message");
				serializer.startTag("", "title");
				serializer.text(msg.getTitle());
				serializer.endTag("", "title");
				serializer.startTag("", "description");
				serializer.text(msg.getDescription());
				serializer.endTag("", "description");
				serializer.endTag("", "message");
			}
			serializer.endTag("", "messages");
			serializer.endDocument();
			return writer.toString();
		} catch (Exception e) {
			throw new RuntimeException(e);
		} 
	} 
}